# -*- coding: utf-8 -*- 

from enum import IntEnum

class OrderType(IntEnum):
        """限价"""
        LMT = 0
        """市价"""
        MKT = 1

class OrderStatus(IntEnum):
        """ 未知""" 
        UnKnow = -1
        """ 未发（下单指令还未发送到下游）"""
        NotSent = 0
        """ 1 已发（下单指令已发送给下游）"""
        Sended = 1
        """ 2 已报（下单指令已报给交易所）"""
        Accepted = 2
        """ 部分成交 """
        PartiallyFilled = 3
        """ 4 已撤（可能已经部分成交，要看看filled字段）"""
        Cancelled = 4
        """ 5 全部成交 """
        Filled = 5
        """ 6 已拒绝 """
        Rejected = 6
        """ 7 撤单请求已发送，但不确定当前状态 """
        PendingCancel = 7

class OrderSide(IntEnum):
        """买入"""
        Buy = ord('B')
        """卖出"""
        Sell = ord('S')

class Offset(IntEnum):
        """未知"""
        UnKnow = 0
        """开仓""" 
        Open = 1
        """平仓 """ 
        Close = 2
        """ 平今 """
        CloseToday = 3
        """ 平昨 """
        CloseYesterday = 4

class Exchange(IntEnum):
        """未知"""
        UnKnow = 0
        """上交所"""
        SHSE = 1
        """深交所"""
        SZSE = 2
        """中金所"""
        CFFEX = 3
        """上期所"""
        SHFE = 4
        """大商所"""
        DCE = 5
        """郑商所"""
        CZCE = 6
        """港交所"""
        HKSE = 7
        """纳斯达克"""
        NASDAQ = 8
        """纽约证券交易所"""
        NYSE = 9
        """全美证券交易所"""
        AMEX = 10
        """新三板"""
        SBSE = 11
        """伦敦商品交易所"""
        LME = 12
        """马来西亚衍生产品交易所"""
        BMD = 13
        """东京商品交易所"""
        TOCOM = 14
        """上海国际能源交易中心"""
        INE = 15

class ContractType(IntEnum):
        """合约类型"""

        """未知"""
        UnKnow = 0
        """股票"""
        Stock = 1
        """期货"""
        Future = 2
        """期权"""
        Option = 3

class ContDetailType(IntEnum):
        """合约细分类型"""

        """常规合约"""
        Default = 1
        """主连合约"""
        Main = 2
        """指数合约"""
        Index = 3

class Currency(IntEnum):
		"""人民币"""
		CNY = 0
		"""美元"""
		USD = 1
		"""港币"""
		HKD = 2

class PosSide(IntEnum):
        """净持仓"""
        Net = 0
        """多仓"""
        Long = 1
        """空仓"""
        Short = 2


# -*- coding: utf-8 -*-
from inquant.biztypes.AssetInfo import *
from inquant.biztypes.BarData import *
from inquant.biztypes.Contract import *
from inquant.biztypes.Order import *
from inquant.biztypes.Position import *
from inquant.biztypes.StrategyEnums import *
from inquant.biztypes.TickData import *



# -*- coding: utf-8 -*- 

from datetime import *
from inquant.biztypes.StrategyEnums import *

class Contract(object):
    """合约信息"""

    def __init__(self):
        """代码"""
        self.Symbol = ""

        """名称"""
        self.ContractName = ""

        """交易所"""
        self.Exchange = Exchange.UnKnow

        """投资品种类型"""
        self.ContractType = ContractType.UnKnow

        """合约细分类型"""
        self.ContDetailType = ContDetailType.Default

        """每股手数"""
        self.Lots = 1

        """最小价差"""
        self.PriceStep = 0

        """到期日"""
        self.ExpiryDate = datetime.now()

        """行权价"""
        self.StrikePx = 0.0

        """期权类型 P:Put C:Call"""
        self.Right = ""

        """上市日期"""
        self.ListingDate = datetime.now()

        """币种"""
        self.Currency = Currency.CNY

        """交易时间"""
        self.TradingTimes = []

class TradingTime(object):
    """交易时间"""

    def __init__(self):
        """开始时间"""
        self.Begin = ""

        """结束时间"""
        self.End = ""



# -*- coding: utf-8 -*-
import threading
import datetime
from time import sleep
import traceback
import os
import sys
from inquant.biztypes import *
import clr
import System

#add current path to prevent python file debug error
currPath = os.path.dirname(__file__)
libpath = os.path.abspath(os.path.join(currPath,"libs"))
sys.path.insert(0,libpath)

#add current path to prevent packaging exe error
libpath = os.path.abspath(os.path.dirname(sys.argv[0]))
sys.path.insert(0,libpath)

clr.AddReference('InQuant.OpenApi')
import InQuant.OpenApi

class StrategyTemplate(object):
    """
    策略模板
    """
    def __init__(self):
        """构造函数"""
        #策略服务
        self.__strategyService = InQuant.OpenApi.StrategyService()
        self.__strategyService.OnTick += System.Action[InQuant.OpenApi.TickData](self.__OnTick)
        self.__strategyService.OnBar += System.Action[InQuant.OpenApi.BarData](self.__OnBar)
        self.__strategyService.OnOrderChanged += System.Action[InQuant.OpenApi.Order](self.__OnOrderChanged)

    def Init(self, cfgPath,logPath):
        """初始化"""
        if not os.path.isfile(cfgPath):
            cfgPath = os.path.abspath(os.path.join(os.path.dirname(sys.argv[0]),cfgPath))
        self.WriteInfo("加载配置文件:" + cfgPath)
        resp = self.__strategyService.Init(cfgPath,logPath)

        #检查返回值
        if not resp:
            return False
        if resp.IsError:
            self.WriteError(resp.ErrorMsg)
            return False
        return True

    def CreateScheduler(self,schedulerFunc,times):
        """创建定时任务
        schedulerFunc : 定时任务回调函数
        times : 定时触发时间，如[90000,161005]，每日9点0分0秒和16点10分5秒触发schedulerFunc"""
        if not schedulerFunc or not times:
            return False
        t = threading.Thread(target=self.__SchedulerCallback,args=(schedulerFunc,times,))
        t.setDaemon(True)
        t.start()

    def __SchedulerCallback(self,schedulerFunc,times):
        """定时任务回调"""
        if not schedulerFunc or not times:
            return

        preExecTime = 0
        while(True):
            try:
                timeStr = datetime.now().strftime('%Y%m%d%H%M%S')
                currTime = int(timeStr)
                if (preExecTime != currTime and currTime % 1000000 in times):
                    self.WriteInfo("run scheduler:" + timeStr)
                    preExecTime = currTime
                    schedulerFunc()
            except Exception as e:
                self.WriteError(str(e),True)
            sleep(0.2)

    def Start(self):
        """启动"""
        resp = self.__strategyService.Start()
        #检查返回值
        if not resp:
            return False
        if resp.IsError:
            self.WriteError(resp.ErrorMsg)
            return False
        return True

    def SendOrder(self, symbol, exchange, orderSide, price, quantity, orderType, offset=Offset.UnKnow, clientOrderID=''):
        """发送委托请求"""
        resp = self.__strategyService.SendOrder(clientOrderID, symbol, exchange, orderSide, price, quantity, orderType, offset)
        
        #检查返回值
        if not resp:
            return False
        if resp.IsError:
            self.WriteError(resp.ErrorMsg)
            return False
        self.WriteInfo(str([symbol, exchange, orderSide, price, quantity, orderType, offset, clientOrderID, resp.ErrorMsg]))
        return True

    def CancelOrder(self,orderID):
        """撤单"""
        resp = self.__strategyService.CancelOrder(orderID)
        
        #检查返回值
        if not resp:
            return False
        if resp.IsError:
            self.WriteError(resp.ErrorMsg)
            return False
        return True

    def GetAssetInfo(self):
        """查询资产信息"""
        resp = self.__strategyService.GetAssetInfo()

        #检查返回值
        if not resp:
            return None
        if resp.IsError:
            self.WriteError(resp.ErrorMsg)
            return None
        if not resp.Data:
            return None
        return self.__ToAssetInfo(resp.Data)
    
    def GetOrder(self,clientOrderID):
        """根据clientOrderID 获取订单详情"""
        resp = self.__strategyService.GetOrder(clientOrderID)
        
        #检查返回值
        if not resp:
            return None
        if resp.IsError:
            self.WriteError(resp.ErrorMsg)
            return None
        if not resp.Data:
            return None
        return self.__ToOrder(resp.Data)

    def GetOpenOrders(self):
        """获取打开的订单"""
        resp = self.__strategyService.GetOpenOrders()

        #检查返回值
        if not resp:
            return None
        if resp.IsError:
            self.WriteError(resp.ErrorMsg)
            return None
        if not resp.Data:
            return list()

        #格式化
        orderlist = list()
        for item in resp.Data:
            order = self.__ToOrder(item)
            orderlist.append(order)
        return orderlist

    def GetOrders(self):
        """获取当日委托"""
        resp = self.__strategyService.GetOrders()
        
        #检查返回值
        if not resp:
            return None
        if resp.IsError:
            self.WriteError(resp.ErrorMsg)
            return None
        if not resp.Data:
            return list()

        #格式化
        orderlist = list()
        for item in resp.Data:
            order = self.__ToOrder(item)
            orderlist.append(order)
        return orderlist

    def GetPositions(self):
        """查询当前持仓"""
        resp = self.__strategyService.GetPositions()

        #检查返回值
        if not resp:
            return None
        if resp.IsError:
            self.WriteError(resp.ErrorMsg)
            return None
        if not resp.Data:
            return list()

        #格式化
        posList = list()
        for item in resp.Data:
            pos = self.__ToPosition(item)
            posList.append(pos)
        return posList

    def GetContract(self,symbol, exchange):
        """获取证券基本信息"""
        resp = self.__strategyService.GetContract(symbol, exchange)
        
        #检查返回值
        if not resp:
            return None
        if resp.IsError:
            self.WriteError(resp.ErrorMsg)
            return None
        if not resp.Data:
            return None
        return self.__ToContract(resp.Data)

    def GetFutContracts(self,varietyCode, exchange, futType):
        """根据品种代码获取证券基本信息
        varietyCode : 品种代码
        exchange : 交易所
        contDetailType : 期货合约类型 -1:获取所有合约 0:获取主力合约 1:常规合约 2:主连合约 3:指数合约"""
        resp = self.__strategyService.GetFutContracts(varietyCode, exchange, futType)

        #检查返回值
        if not resp:
            return None
        if resp.IsError:
            self.WriteError(resp.ErrorMsg)
            return None
        if not resp.Data:
            return list()
        #格式化
        contractlist = list()
        for item in resp.Data:
            contract = self.__ToContract(item)
            contractlist.append(contract)
        return contractlist
    
    def GetLastTick(self, symbol, exchange, count=1):
        """获取最近几笔TICK行情"""
        resp = self.__strategyService.GetLastTick(symbol,exchange,count)

        #检查返回值
        if not resp:
            return None
        if resp.IsError:
            self.WriteError(resp.ErrorMsg)
            return None
        if not resp.Data:
            return list()
        #格式化
        ticklist = list()
        for item in resp.Data:
            tick = self.__ToTick(item)
            ticklist.append(tick)
        return ticklist

    def GetLastBar(self, symbol, exchange, barType, count=1):
        """获取最近几笔BAR行情"""
        resp = self.__strategyService.GetLastBar(symbol,exchange,barType,count)

        #检查返回值
        if not resp:
            return None
        if resp.IsError:
            self.WriteError(resp.ErrorMsg)
            return None
        if not resp.Data:
            return list()
        #格式化
        barlist = list()
        for item in resp.Data:
            bar = self.__ToBar(item)
            barlist.append(bar)
        return barlist

    def GetHisBar(self, symbol, exchange, barType, count, startTime=None):
        """获取历史行情数据
        symbol : 品种代码
        exchange : 交易所
        barType : K线类型，以秒为单位（1分钟:60 5分钟:6*60 15分钟:15*60 30分钟:30*60 60分钟:60*60 日:24*60*60 月:30*24*60*60 年:365*24*60*60）
        count : K线数量
        startTime : 起始时间:%Y%m%d%H%M%S """

        if not startTime:
            startTime = int(datetime.now().strftime("%Y%m%d%H%M%S"))
        resp = self.__strategyService.GetHisBar(symbol,exchange,barType,startTime,count)

        #检查返回值
        if not resp:
            return None
        if resp.IsError:
            self.WriteError(resp.ErrorMsg)
            return None
        if not resp.Data:
            return list()
        #格式化
        barlist = list()
        for item in resp.Data:
            bar = self.__ToBar(item)
            barlist.append(bar)
        return barlist

    def WriteError(self, log, islogtrace=False):
        """写错误日志"""
        print(log)
        self.__strategyService.WriteLog("strategyError", log)
        if islogtrace:
            tracelog = traceback.format_exc()
            print(tracelog)
            self.__strategyService.WriteLog("strategyError", tracelog)

    def WriteInfo(self, log):
        """写一般日志"""
        print(log)
        self.__strategyService.WriteLog("strategy", log)

    def OnBar(self,bar):
        """当有Bar数据推送来的时候做的处理"""
        pass

    def OnTick(self,tick):
        """当有Tick数据推送来的时候做的处理"""
        pass

    def OnOrderChanged(self,order):
        """当有成交回报推送来的时候做的处理"""
        pass

    def __OnTick(self, tickData): 
        """Net类型转化为Python类型"""
        if tickData == None:
            return
        try:
            tick = self.__ToTick(tickData)
            self.OnTick(tick)
        except Exception as e:
            self.WriteError(str(e),True) 

    def __OnBar(self,barData):
        """Net类型转化为Python类型"""
        if barData == None:
            return
        try:
            bar = self.__ToBar(barData)
            self.OnBar(bar)
        except Exception as e:
            self.WriteError(str(e),True)

    def __OnOrderChanged(self,orderData):
        """Net类型转化为Python类型"""
        if orderData == None:
            return
        try:
            order = self.__ToOrder(orderData)
            self.OnOrderChanged(order)
        except Exception as e:
            self.WriteError(str(e),True)

    def __ToContract(self,data):
        """Net类型转化为Python类型"""
        if not data:
            return None
        contract = Contract()
        contract.Symbol = data.Symbol
        contract.ContractName = data.ContractName
        contract.Exchange = Exchange(data.Exchange)
        contract.ContractType = ContractType(data.ContractType)
        contract.Lots = data.Lots
        contract.PriceStep = data.PriceStep
        contract.ExpiryDate = self.__ToDateTime(data.ExpiryDate)
        contract.StrikePx = data.StrikePx
        contract.Right = data.Right
        contract.ListingDate = self.__ToDateTime(data.ListingDate)
        contract.Currency = Currency(data.Currency)
        contract.ContDetailType = ContDetailType(data.ContDetailType)

        for x in data.TradingTimes:
            tradingTime = TradingTime()
            tradingTime.Begin = x.Begin
            tradingTime.End = x.End
            contract.TradingTimes.append(tradingTime)

        return contract

    def __ToBar(self,data):
        """Net类型转化为Python类型"""
        if not data:
            return None
        bar = BarData()
        bar.BarType = data.BarType
        bar.Exchange = Exchange(data.Exchange)
        bar.HighPx = data.HighPx
        bar.LowPx = data.LowPx
        bar.LastPx = data.LastPx
        bar.LocalTime = self.__ToDateTime(data.LocalTime)
        bar.PreClosePx = data.PreClosePx
        bar.Symbol = data.Symbol
        bar.Volume = data.Volume
        bar.OpenPx = data.OpenPx
        return bar

    def __ToTick(self,data):
        """Net类型转化为Python类型"""
        if not data:
            return None
        tick = TickData()
        tick.Symbol = data.Symbol
        tick.Exchange = Exchange(data.Exchange)
        tick.LocalTime = self.__ToDateTime(data.LocalTime)
        tick.LastPx = data.LastPx
        tick.Volume = data.Volume
        tick.OpenInterest = data.OpenInterest
        tick.OpenPx = data.OpenPx
        tick.HighPx = data.HighPx
        tick.LowPx = data.LowPx
        tick.PreClosePx = data.PreClosePx

        for x in data.Bids:
            unit = LevelUnit()
            unit.Px = x.Px
            unit.Vol = x.Vol
            tick.Bids.append(unit)

        for x in data.Asks:
            unit = LevelUnit()
            unit.Px = x.Px
            unit.Vol = x.Vol
            tick.Asks.append(unit)
        return tick

    def __ToOrder(self,data):
        """Net类型转化为Python类型"""
        if not data:
            return None
        order = Order()
        order.Exchange = Exchange(data.Exchange)
        order.Filled = data.Filled
        order.FilledPx = data.FilledPx
        order.FilledTime = self.__ToDateTime(data.FilledTime)
        order.Note = data.Note
        order.Offset = Offset(data.Offset)
        order.OrderID = data.OrderID
        order.OrderSide = OrderSide(data.OrderSide)
        order.OrderTime = self.__ToDateTime(data.OrderTime)
        order.OrderType = OrderType(data.OrderType)
        order.Price = data.Price
        order.Quantity = data.Quantity
        order.Status = OrderStatus(data.Status)
        order.Symbol = data.Symbol
        order.TradeDate = self.__ToDateTime(data.TradeDate)
        order.StrategyID = data.StrategyID
        return order

    def __ToPosition(self,data):
        """根据clientOrderID 获取订单详情"""
        if not data:
            return None
        pos = Position()
        pos.StrategyID = data.StrategyID
        pos.Symbol = data.Symbol
        pos.Exchange = Exchange(data.Exchange)
        pos.Quantity = data.Quantity
        pos.Frozen = data.Frozen
        pos.CostPx = data.CostPx
        pos.PosSide = PosSide(data.PosSide)
        pos.Margin = data.Margin
        return pos

    def __ToAssetInfo(self,data):
        """根据clientOrderID 获取订单详情"""
        if not data:
            return None
        asset = AssetInfo()
        asset.Currency = Currency(data.Currency)
        asset.StrategyID = data.StrategyID
        asset.TotalAsset = data.TotalAsset
        asset.Available = data.Available
        asset.Margin = data.Margin
        asset.Balance = data.Balance
        return asset

    def __ToDateTime(self,src):
        return src.ToString("yyyy-MM-dd HH:mm:ss")

if __name__ == '__main__':
   
    strategy = StrategyTemplate()
    strategy.Init("demo.json")
    strategy.Start()



# -*- coding: utf-8 -*-
#import sys
#sys.path.append('../../')
from inquant import *

class MyStrategy(StrategyTemplate):
    """我的策略"""

    def __init__(self):
        """构造函数"""
        super(MyStrategy,self).__init__()

        self.isfirst = 0

    def OnTick(self, data):
        """Tick数据处理 注data参数一次只有一条tick数据"""
        print("tickqqqqq",data.Symbol,data.LocalTime,data.Exchange)


        pass

    def OnBar(self, data):
        """Bar数据处理 注data参数一次只有一条bar数据"""
        print("bar11",data.Symbol,data.LocalTime,data.Exchange)

        #resp10 = strategy.GetLastBar(data.Symbol,data.Exchange,data.BarType,5)

        #if self.isfirst == 0:
        #    self.isfirst = 1
        #    resp4 =
        #    strategy.SendOrder(data.Symbol,data.Exchange,OrderSide.Sell,data.LastPx,1,OrderType.LMT,Offset.Close)

        pass

    def OnOrderChanged(self,order):
        """成交回报处理"""
        pass

    def TaskCallback(self):
        print(datetime.now().time())

if __name__ == '__main__':
    #新建策略
    strategy = MyStrategy()

    ret = strategy.GetHisBar("rb1901",Exchange.SHFE,60 * 60,1000,20181015150000)

    #创建定时任务
    strategy.CreateScheduler(strategy.TaskCallback,[90000,161005])

    #contracts = strategy.GetFutContracts('rb',Exchange.SHFE,-1)
    #contracts = strategy.GetFutContracts('rb',Exchange.SHFE,0)
    #contracts = strategy.GetFutContracts('rb',Exchange.SHFE,1)
    #contracts = strategy.GetFutContracts('rb',Exchange.SHFE,2)
    #contracts = strategy.GetFutContracts('rb',Exchange.SHFE,3)

    strategy.WriteInfo(u"开始初始化策略...")
    #初始化
    ret = strategy.Init("demo.json","d:\\strategylog\\")
    if not ret:
        strategy.WriteError("u初始化策略失败！！！")
        input(u"按任意键退出")
        sys.exit()
    strategy.WriteInfo(u"初始化策略成功")

    strategy.WriteInfo(u"开始启动策略...")
    resp = strategy.Start()
    if not resp:
        strategy.WriteError(u"策略启动失败！！")
        input(u"按任意键退出")
        sys.exit()
    strategy.WriteInfo(u"策略启动成功")

    resp4 = strategy.SendOrder('rb1901',Exchange.SHFE,OrderSide.Buy,4166,1,OrderType.LMT,Offset.Open)
    resp5 = strategy.CancelOrder('7ba0ab1c8319442299c835269f600f3f')

    resp1 = strategy.GetAssetInfo()
    resp2 = strategy.GetOrders()
    resp3 = strategy.GetPositions()
        
    resp6 = strategy.GetOrder('7ba0ab1c8319442299c835269f600f3f')
    resp7 = strategy.GetOpenOrders()
    resp8 = strategy.GetContract('rb1901',Exchange.SHFE)
    resp9 = strategy.GetLastTick('rb1901',Exchange.SHFE,2)
    resp10 = strategy.GetLastBar('rb1901',Exchange.SHFE,300,5)

    input(u"策略执行中，按任意键退出...")


# -*- coding: utf-8 -*- 

from datetime import  *  
from inquant.biztypes.StrategyEnums import *

class Order(object):
    """委托"""

    def __init__(self):
        """策略编号"""
        self.StrategyID = ""
        """委托ID"""
        self.OrderID = ""
        """股票代码或合约代码"""
        self.Symbol = ""
        """交易所"""
        self.Exchange = Exchange.UnKnow
        """委托方向"""
        self.OrderSide = OrderSide.Buy
        """开仓还是平仓 (期货中使用) 非期货为None"""
        self.Offset = Offset.UnKnow
        """委托数量"""
        self.Quantity = 0
        """委托价格"""
        self.Price = 0.0
        """成交数量"""
        self.Filled = 0
        """成交金额"""
        self.FilledPx = 0.0
        """委托时间"""
        self.OrderTime = datetime.now()
        """委托状态"""
        self.Status = OrderStatus.UnKnow
        """委托类型"""
        self.OrderType = OrderType.LMT
        """交易日"""
        self.TradeDate = datetime.now()
        """成交时间"""
        self.FilledTime = datetime.now()
        """委托备注"""
        self.Note = ""

        



# -*- coding: utf-8 -*- 

from inquant.biztypes.StrategyEnums import *

class Position(object):
    """持仓信息"""

    def __init__(self):
        """策略编号"""
        self.StrategyID = ""
        """合约代码"""
        self.Symbol = ""
        """交易所"""
        self.Exchange = Exchange.UnKnow
        """持仓数量"""
        self.Quantity = 0
        """冻结数量"""
        self.Frozen = 0
        """持仓成本"""
        self.CostPx = 0.0
        """持仓方向"""
        self.PosSide = PosSide.Net
        """保证金"""
        self.Margin = 0.0



# -*- coding: utf-8 -*- 

from datetime import *
from inquant.biztypes.StrategyEnums import *

class TickData(object):
    """实时数据模型"""

    def __init__(self):
        """股票代码或合约名称"""
        self.Symbol = ""
        """交易所"""
        self.Exchange = Exchange.UnKnow
        """时间"""
        self.LocalTime = datetime.now()
        """最新成交价"""
        self.LastPx = 0.0
        """成交量"""
        self.Volume = 0
        """持仓量"""
        self.OpenInterest = 0
        """开盘价"""
        self.OpenPx = 0.0
        """最高价"""
        self.HighPx = 0.0
        """最低价"""
        self.LowPx = 0.0
        """昨收"""
        self.PreClosePx = 0.0
        """买N档"""
        self.Bids = []
        """卖N档"""
        self.Asks = []

class LevelUnit(object):
    """一档行情"""

    def __init__(self):
        """价格"""
        self.Px = 0
        """量"""
        self.Vol = 0


# -*- coding: utf-8 -*- 

from inquant.biztypes.StrategyEnums import *

class AssetInfo(object):
    """资产信息"""

    def __init__(self):
        """券商账户编号"""
        self.StrategyID = ""
        """总资产"""
        self.TotalAsset = 0.0
        """可用资金"""
        self.Available = 0.0
        """余额"""
        self.Balance = 0.0
        """保证金"""
        self.Margin = 0.0
        """币种"""
        self.Currency = Currency.CNY

    


import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(name="inquant",
    version="1.1.9",
    author="inquant",
    author_email="sunliusi@hotmail.com",
    description="inquant future quant api",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="http://www.inquantstudio.com/",
    packages=setuptools.find_packages(),
    install_requires=['pythonnet>=2.3.0',],
    package_data = {
        '': ['*.dll','*.json','*.bat'],
    },
    classifiers=['Programming Language :: Python',
        'Programming Language :: Python :: Implementation',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",],)
